pub struct EnvCredentials { /* private fields */ }Expand description
Credentials provider that reads from environment variables.
By default, reads from KRAKEN_API_KEY and KRAKEN_API_SECRET.
Implementations
Sourceimpl EnvCredentials
impl EnvCredentials
Sourcepub fn from_env() -> Self
pub fn from_env() -> Self
Create credentials from default environment variables.
Reads KRAKEN_API_KEY and KRAKEN_API_SECRET.
Panics
Panics if the environment variables are not set.
Sourcepub fn from_env_vars(key_var: &str, secret_var: &str) -> Self
pub fn from_env_vars(key_var: &str, secret_var: &str) -> Self
Create credentials from custom environment variable names.
Panics
Panics if the environment variables are not set.
Sourcepub fn try_from_env() -> Option<Self>
pub fn try_from_env() -> Option<Self>
Try to create credentials from default environment variables.
Returns None if the environment variables are not set.
Sourcepub fn try_from_env_vars(key_var: &str, secret_var: &str) -> Option<Self>
pub fn try_from_env_vars(key_var: &str, secret_var: &str) -> Option<Self>
Try to create credentials from custom environment variable names.
Returns None if the environment variables are not set.