pub trait NonceProvider: Send + Sync {
// Required method
fn next_nonce(&self) -> u64;
}Expand description
Trait for providing nonces for authenticated requests.
The nonce must be strictly increasing for each request. Kraken recommends using a timestamp-based approach.
Required Methods
Sourcefn next_nonce(&self) -> u64
fn next_nonce(&self) -> u64
Generate the next nonce value.
This value must be greater than any previously returned value.